@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-"""Logging Handler integrating RabbitMQ and Graylog Extended Log Format (GELF)
-handler"""
+"""Logging Handler integrating RabbitMQ and
+Graylog Extended Log Format (GELF)"""
 
 import json
 from logging import Filter
@@ -23,26 +23,32 @@ _ifnone = lambda v, x: x if v is None else v
 
 
 class GELFRabbitHandler(BaseGELFHandler, SocketHandler):
-    """RabbitMQ / Graylog Extended Log Format handler
+    """RabbitMQ / GELF handler
 
     .. note::
 
         This handler ignores all messages logged by amqplib.
     """
 
-    def __init__(self, url, exchange='logging.gelf', exchange_type='fanout',
-                 virtual_host='/', routing_key='', **kwargs):
+    def __init__(
+        self,
+        url,
+        exchange="logging.gelf",
+        exchange_type="fanout",
+        virtual_host="/",
+        routing_key="",
+        **kwargs
+    ):
         """Initialize the GELFRabbitHandler
 
         :param url: RabbitMQ URL (ex: amqp://guest:guest@localhost:5672/)
         :type url: str
 
-        :param exchange: RabbitMQ exchange. (default 'logging.gelf').
-            A queue binding must be defined on the server to prevent
-            log messages from being dropped.
+        :param exchange: RabbitMQ exchange. A queue binding must be defined
+            on the server to prevent GELF logs from being dropped.
         :type exchange: str
 
-        :param exchange_type: RabbitMQ exchange type (default 'fanout').
+        :param exchange_type: RabbitMQ exchange type.
         :type exchange_type: str
 
         :param virtual_host:
@@ -53,32 +59,31 @@ class GELFRabbitHandler(BaseGELFHandler, SocketHandler):
         """
         self.url = url
         parsed = urlparse(url)
-        if parsed.scheme != 'amqp':
+        if parsed.scheme != "amqp":
             raise ValueError('invalid URL scheme (expected "amqp"): %s' % url)
-        host = parsed.hostname or 'localhost'
+        host = parsed.hostname or "localhost"
         port = _ifnone(parsed.port, 5672)
-        self.virtual_host = virtual_host if not unquote(
-            parsed.path[1:]) else unquote(parsed.path[1:])
+        self.virtual_host = (
+            virtual_host if not unquote(parsed.path[1:]) else unquote(parsed.path[1:])
+        )
         self.cn_args = {
-            'host': '%s:%s' % (host, port),
-            'userid': _ifnone(parsed.username, 'guest'),
-            'password': _ifnone(parsed.password, 'guest'),
-            'virtual_host': self.virtual_host,
-            'insist': False,
+            "host": "%s:%s" % (host, port),
+            "userid": _ifnone(parsed.username, "guest"),
+            "password": _ifnone(parsed.password, "guest"),
+            "virtual_host": self.virtual_host,
+            "insist": False,
         }
         self.exchange = exchange
         self.exchange_type = exchange_type
         self.routing_key = routing_key
-        BaseGELFHandler.__init__(
-            self,
-            **kwargs
-        )
+        BaseGELFHandler.__init__(self, **kwargs)
         SocketHandler.__init__(self, host, port)
-        self.addFilter(ExcludeFilter('amqplib'))
+        self.addFilter(ExcludeFilter("amqplib"))
 
     def makeSocket(self, timeout=1):
-        return RabbitSocket(self.cn_args, timeout, self.exchange,
-                            self.exchange_type, self.routing_key)
+        return RabbitSocket(
+            self.cn_args, timeout, self.exchange, self.exchange_type, self.routing_key
+        )
 
     def makePickle(self, record):
         message_dict = self._make_gelf_dict(record)
@@ -92,8 +97,7 @@ class RabbitSocket(object):
         self.exchange = exchange
         self.exchange_type = exchange_type
         self.routing_key = routing_key
-        self.connection = amqp.Connection(
-            connection_timeout=timeout, **self.cn_args)
+        self.connection = amqp.Connection(connection_timeout=timeout, **self.cn_args)
         self.channel = self.connection.channel()
         self.channel.exchange_declare(
             exchange=self.exchange,
@@ -105,9 +109,7 @@ class RabbitSocket(object):
     def sendall(self, data):
         msg = amqp.Message(data, delivery_mode=2)
         self.channel.basic_publish(
-            msg,
-            exchange=self.exchange,
-            routing_key=self.routing_key
+            msg, exchange=self.exchange, routing_key=self.routing_key
         )
 
     def close(self):
@@ -126,14 +128,16 @@ class ExcludeFilter(Filter):
     def __init__(self, name):
         """Initialize the ExcludeFilter
 
-        :param name: Name to match for within a:class:`logging.LogRecord`'s
+        :param name: Name to match for within a :class:`logging.LogRecord`'s
             ``name`` field for filtering.
         :type name: str
         """
         if not name:
-            raise ValueError('ExcludeFilter requires a non-empty name')
+            raise ValueError("ExcludeFilter requires a non-empty name")
         Filter.__init__(self, name)
 
     def filter(self, record):
-        return not (record.name.startswith(self.name) and (
-            len(record.name) == self.nlen or record.name[self.nlen] == "."))
+        return not (
+            record.name.startswith(self.name)
+            and (len(record.name) == self.nlen or record.name[self.nlen] == ".")
+        )
