@@ -7,20 +7,29 @@ import logging
 
 import pytest
 
-from graypy.handler import SYSLOG_LEVELS, GELFUDPHandler
+from graypy.handler import (
+    SYSLOG_LEVELS,
+    GELFUDPHandler,
+    GELFWarningChunker,
+    BaseGELFChunker,
+    GELFTruncatingChunker,
+)
 
 from tests.helper import TEST_UDP_PORT
 from tests.integration import LOCAL_GRAYLOG_UP
 from tests.integration.helper import get_unique_message, get_graylog_response
 
 
-@pytest.mark.skipif(not LOCAL_GRAYLOG_UP,
-                    reason="local Graylog instance not up")
-def test_chunked_logging():
-    """Test sending a common usage log that requires chunking to be fully
-    sent"""
+@pytest.mark.parametrize(
+    "gelf_chunker", [BaseGELFChunker, GELFWarningChunker, GELFTruncatingChunker]
+)
+@pytest.mark.skipif(not LOCAL_GRAYLOG_UP, reason="local Graylog instance not up")
+def test_chunked_logging(gelf_chunker):
+    """Test sending a log that requires chunking to be fully sent"""
     logger = logging.getLogger("test_chunked_logger")
-    handler = GELFUDPHandler("127.0.0.1", TEST_UDP_PORT, chunk_size=10)
+    handler = GELFUDPHandler(
+        "127.0.0.1", TEST_UDP_PORT, gelf_chunker=gelf_chunker(chunk_size=10)
+    )
     logger.addHandler(handler)
     message = get_unique_message()
     logger.error(message)
